==> vradi-entities-0.2.0-sources.jar: com/jurismarches/vradi/entities/Group.java <==
/*
 * #%L
 * Vradi :: Entities
 * 
 * $Id$
 * $HeadURL$
 * %%
 * Copyright (C) 2009 - 2010 JurisMarches, Codelutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */
package com.jurismarches.vradi.entities;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Date;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Set;
import org.nuiton.wikitty.BusinessEntity;
import org.nuiton.wikitty.BusinessEntityWikitty;
import org.nuiton.wikitty.TreeNode;
import org.nuiton.wikitty.TreeNodeAbstract;
import org.nuiton.wikitty.TreeNodeImpl;
import org.nuiton.wikitty.Wikitty;
import org.nuiton.wikitty.WikittyExtension;
import org.nuiton.wikitty.WikittyUser;
import org.nuiton.wikitty.WikittyUserAbstract;
import org.nuiton.wikitty.WikittyUserImpl;
import org.nuiton.wikitty.WikittyUtil;


public interface Group extends BusinessEntity, QueryMaker {     String EXT_GROUP = "Group";
     String FIELD_GROUP_NAME = "name";
     String FQ_FIELD_GROUP_NAME = EXT_GROUP + ".name";
     String FIELD_GROUP_USER = "user";
     String FQ_FIELD_GROUP_USER = EXT_GROUP + ".user";
    /**
     * getName :
     * @return String 
     */

     String getName();

    /**
     * setName :
     * @param name 
     */

     void setName(String name);

    /**
     * getUser :
     * @return Set<String> 
     */

     Set<String> getUser();

    /**
     * addUser :
     * @param element 
     */

     void addUser(String element);

    /**
     * removeUser :
     * @param element 
     */

     void removeUser(String element);

    /**
     * clearUser :
     */

     void clearUser();

    /**
     * getQueries :
     * @return Set<String> 
     */

     Set<String> getQueries();

    /**
     * addQueries :
     * @param element 
     */

     void addQueries(String element);

    /**
     * removeQueries :
     * @param element 
     */

     void removeQueries(String element);

    /**
     * clearQueries :
     */

     void clearQueries();


} //Group

==> vradi-entities-0.3.2-sources.jar: com/jurismarches/vradi/entities/Group.java <==
/*
 * #%L
 * Vradi :: Entities
 * 
 * $Id$
 * $HeadURL$
 * %%
 * Copyright (C) 2009 - 2010 JurisMarches, Codelutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */
package com.jurismarches.vradi.entities;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Date;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Set;
import org.nuiton.wikitty.BusinessEntity;
import org.nuiton.wikitty.BusinessEntityWikitty;
import org.nuiton.wikitty.Wikitty;
import org.nuiton.wikitty.WikittyExtension;
import org.nuiton.wikitty.WikittyTreeNode;
import org.nuiton.wikitty.WikittyTreeNodeAbstract;
import org.nuiton.wikitty.WikittyTreeNodeImpl;
import org.nuiton.wikitty.WikittyUser;
import org.nuiton.wikitty.WikittyUserAbstract;
import org.nuiton.wikitty.WikittyUserImpl;
import org.nuiton.wikitty.WikittyUtil;


public interface Group extends BusinessEntity, QueryMaker {     String EXT_GROUP = "Group";
     String FIELD_GROUP_NAME = "name";
     String FQ_FIELD_GROUP_NAME = EXT_GROUP + ".name";
     String FIELD_GROUP_USER = "user";
     String FQ_FIELD_GROUP_USER = EXT_GROUP + ".user";
    /**
     * getName :
     * @return String 
     */

     String getName();

    /**
     * setName :
     * @param name 
     */

     void setName(String name);

    /**
     * getUser :
     * @return Set<String> 
     */

     Set<String> getUser();

    /**
     * addUser :
     * @param element 
     */

     void addUser(String element);

    /**
     * removeUser :
     * @param element 
     */

     void removeUser(String element);

    /**
     * clearUser :
     */

     void clearUser();

    /**
     * getQueries :
     * @return Set<String> 
     */

     Set<String> getQueries();

    /**
     * addQueries :
     * @param element 
     */

     void addQueries(String element);

    /**
     * removeQueries :
     * @param element 
     */

     void removeQueries(String element);

    /**
     * clearQueries :
     */

     void clearQueries();


} //Group
